Utilities for safely obtaining OwnedFds for inherited file descriptors.
Enums
- Inherited
FdError - Errors that can occur while taking an ownership of
RawFd
Functions
- init_
inherited_ ⚠fds - Takes ownership of all open file descriptors in this process other than standard
input/output/error, so that they can later be obtained by calling
take_fd_ownership. - take_
fd_ ownership - Takes the ownership of the given
RawFdand returns anOwnedFdfor it.