Module inherited

Module inherited 

Utilities for safely obtaining OwnedFds for inherited file descriptors.

Enums

InheritedFdError
Errors that can occur while taking an ownership of RawFd

Functions

init_inherited_fds
Takes ownership of all open file descriptors in this process other than standard input/output/error, so that they can later be obtained by calling take_fd_ownership.
take_fd_ownership
Takes the ownership of the given RawFd and returns an OwnedFd for it.